@@ -138,13 +138,14 @@ do_ <- function() {
         url <- sprintf("https://api-fx%s.oanda.com/v3/accounts/%s/instruments",
                        switch(server, practice = "practice", live = "trade"),
                        do_$getAccount(server = server, apikey = apikey))
-        resp <- ncurl(url, convert = FALSE, follow = TRUE,
-                      headers = c("Authorization" = strcat("Bearer ", apikey),
-                                  "User-Agent" = .user_agent))
-        resp[["status"]] == 200L ||
-          stop("status code ", resp[["status"]], " - ", deserialize_json(resp[["data"]]), call. = FALSE)
+        for (i in seq_len(2L)) {
+          resp <- ncurl(url, convert = FALSE, follow = TRUE,
+                        headers = c("Authorization" = strcat("Bearer ", apikey),
+                                    "User-Agent" = .user_agent))
+          resp[["status"]] == 200L && break
+        }
         parsed <- deserialize_json(resp[["data"]])
-        length(parsed[["instruments"]]) || {
+        is.list(parsed) && length(parsed[["instruments"]]) || {
           warning(parsed,
                   "\nInstruments list could not be retrieved - falling back to internal data",
                   "\nCached instruments list will be used for the rest of the session", call. = FALSE)
